==> nocc-1.8.3.tbz: www/nocc/lang/ka.php <==
<?php
/**
 * Language configuration file for NOCC
 *
 * Copyright 2001 Nicolas Chalanset <nicocha@free.fr>
 * Copyright 2001 Olivier Cahagne <cahagn_o@epita.fr>
 *
 * This file is part of NOCC. NOCC is free software under the terms of the
 * GNU General Public License. You should have received a copy of the license
 * along with NOCC.  If not, see <http://www.gnu.org/licenses/>.
 *
 * @package    NOCC
 * @subpackage Translations
 * @license    http://www.gnu.org/licenses/ GNU General Public License
 * @version    SVN: $Id: ka.php 2181 2010-04-27 09:07:03Z gerundt $
 */

/** Georgian (ქართული)
 *
 * See the qqq 'language' for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author გიორგიმელა
 */

$default_date_format = '%d.%m.%Y';
$no_locale_date_format = '%d.%m.%Y';
$default_time_format = '%H:%M';
$err_user_empty = 'სახელის ველი ცარიელია';
$err_passwd_empty = 'პაროლის ველი ცარიელია';
$alt_delete = 'წაშალეთ არჩეული წერილები';
$alt_delete_one = 'წაშალეთ ეს წერილები';
$alt_new_msg = 'ახალი წერილი';
$alt_reply = 'უპასუხეთ ავტორს';
$alt_reply_all = 'უპასუხეთ ყველას';
$alt_forward = 'გაგზავნა';
$alt_next = 'შემდეგი';
$alt_prev = 'წინა';
$title_next_page = 'შემდეგი გვერდი';
$title_prev_page = 'წინა გვერდი';
$title_next_msg = 'შემდეგი შეტყობინება';
$title_prev_msg = 'წინა წერილი';
$html_theme_label = 'გაფორმება:';
$html_welcome = 'კეთილი იყოს თქვენი მობრძანება %1$s';
$html_login = 'შესვლა';
$html_user_label = 'მომხმარებელი:';
$html_passwd_label = 'პაროლი';
$html_submit = 'შენახვა';
$html_help = 'დახმარება';
$html_server_label = 'სერვერი:';
$html_wrong = 'პაროლი ან ანგარიშის სახელი არასწორია';
$html_retry = 'გამეორება';
$html_remember = 'დაიმახსოვრება';
$html_lang_label = 'ენა:';
$html_msgperpage_label = 'წერილები ერთ გვერდზე:';
$html_preferences = 'კონფიგურაცია';
$html_full_name_label = 'სრული სახელი:';
$html_email_address_label = 'ელექტრონული ფოსტის მისამართი:';
$html_ccself = 'დაიტოვეთ ასლი';
$html_hide_addresses = 'დამალეთ მისამართი';
$html_outlook_quoting = 'ციტირება Outlook-ის სტილში';
$html_reply_to = 'უპასუხეთ';
$html_use_signature = 'გამოიყენეთ ხელმოწერა';
$html_signature = 'ხელმოწერ';
$html_signature_label = 'ხელმოწერა:';
$html_reply_leadin_label = 'პასუხის შესავალი:';
$html_prefs_updated = 'კონფიგურაცია განახლდა';
$html_manage_folders_link = 'IMAP ფოლდერების მართვა';
$html_manage_filters_link = 'საფოსტო ფილტრების მართვა';
$html_use_graphical_smilies = 'გამოიყენეთ გრაფიკული სმაილები';
$html_sent_folder_label = 'გაგზავნილი წერილების ასლების შენახვა სპეციალურ ფოლდერში';
$html_trash_folder_label = 'წაშლილი წერილების გადატანა სპეციალურ ფოლდერში:';
$html_colored_quotes = 'გაფერადებული ციტატები';
$html_display_struct = 'სტრუქტურის ტექსტის ჩვენება';
$html_send_html_mail = 'გაგზავნეთ წერილები HTML ფორმატში';
$html_folders = 'ფოლდერები';
$html_folders_create_failed = 'ფოლდერი ვერ შეიქმნა!';
$html_folders_sub_failed = 'ფოლდერის გამოწერა შეუძლებელია!';
$html_folders_unsub_failed = 'ფოლდერიდან გამოწერის შეწყვეტა შეუძლებელია';
$html_folders_rename_failed = 'ფოლდერის სახელის შეცვლა შეუძლებელია';
$html_folders_updated = 'ფოლდერები შენახულია';
$html_folder_subscribe = 'გამოწერა';
$html_folder_rename = 'სახელის შეცვლა';
$html_folder_create = 'ახალი ფოლდერის შექმნა ახალი სახელით';
$html_folder_remove = 'გამოწერის შეწყვეტა';
$html_folder_delete = 'წაშლა';
$html_folder_to = 'მდე';
$html_filter_remove = 'წაშლა';
$html_filter_body = 'წერილის სხეული';
$html_filter_subject = 'წერილის თემა';
$html_filter_to = '"ვის" ველი';
$html_filter_cc = '"ასლი" ველი';
$html_filter_from = '"ვისგან" ველი';
$html_filter_change_tip = 'ცვლილებების შესატანად უბრალოდ გადაწერეთ ფილტრი';
$html_reapply_filters = 'ფილტრების თავიდან ჩართვა';
$html_filter_contains = 'შეიცავს';
$html_filter_name = 'ფილტრის სახელი';
$html_filter_action = 'ფილტრის მოქმედება';
$html_filter_moveto = 'გადატანა';
$html_select_one = '--აირჩიეთ რომელიმე--';
$html_and = 'და';
$html_new_msg_in = 'ახალი შეტყობინებები';
$html_or = 'ან';
$html_move = 'გადატანა';
$html_copy = 'ასლის შექმნა';
$html_messages_to = 'არჩეული წერილები';
$html_gotopage = 'გადატანა გვერდზე';
$html_gotofolder = 'გადასვლა ფოლდერში';
$html_other_folders = 'ფოლდერების სია';
$html_page = 'გვერდი';
$html_of = 'დან';
$html_view_header = 'წერილის სათაურის ხილვა';
$html_remove_header = 'სათაურის დამალვა';
$html_inbox = 'შესული წერილები';
$html_new_msg = 'წერა';
$html_reply = 'პასუხი';
$html_reply_short = 'ვის:';
$html_reply_all = 'უპასუხეთ ყველას';
$html_forward = 'გადაგზავნა';
$html_forward_short = 'წინ:';
$html_forward_info = 'გაგზავნილი წერილი იქნება გადაგზავნილი როგორც ამის მიმაგრება.';
$html_delete = 'წაშლა';
$html_new = 'ახალი';
$html_mark = 'წაშლა';
$html_att_label = 'მიმაგრებული ფაილი:';
$html_atts_label = 'მიმაგრებული ფაილი:';
$html_unknown = '[უცნობია]';
$html_attach = 'ფაილის მიმაგრება';
$html_attach_forget = 'თქვენ უნდა მიამაგროთ ფაილი წერილის გაგზავნამდე';
$html_attach_delete = 'არჩეულის წაშლა';
$html_attach_none = 'თქვენ შეგიძლიათ აირჩიოთ ფაილი კავშირის დასამყარებლად';
$html_sort_by = 'სორტირება';
$html_sort = 'სორტირება';
$html_from = 'გან';
$html_from_label = 'გან:';
$html_subject = 'თემა';
$html_subject_label = 'თემა:';
$html_date = 'თარიღი';
$html_date_label = 'თარიღი:';
$html_sent_label = 'გაიგზავნა:';
$html_wrote = 'დაწერა';
$html_size = 'ზომა';
$html_totalsize = 'სულ ზომა';
$html_kb = 'კბ';
$html_mb = 'მბ';
$html_gb = 'გბ';
$html_bytes = 'ბ';
$html_filename = 'ფაილის სახელი';
$html_to = 'ვის';
$html_to_label = 'ადრესატი:';
$html_cc = 'ასლი';
$html_cc_label = 'ასლი:';
$html_bcc_label = 'Bcc:';
$html_nosubject = 'არ არის თემა';
$html_send = 'გაგზავნა';
$html_cancel = 'გაუქმება';
$html_no_mail = 'წერილები არ არის.';
$html_logout = 'გასვლა';
$html_msg = 'წერილი';
$html_msgs = 'წერილები';
$html_configuration = 'ეს სერვერი არის არასწორედ დაყენებული!';
$html_priority = 'პრიორიტეტი';
$html_priority_label = 'პრიორიტეტი:';
$html_lowest = 'ყველაზე დაბალი';
$html_low = 'დაბალი';
$html_normal = 'ნორმალური';
$html_high = 'მაღალი';
$html_highest = 'ყველაზე მაღალი';
$html_flagged = 'მონიშნული';
$html_receipt = 'მოითხოვეთ წაკითხვის დადასტურება';
$html_select = 'არჩევა';
$html_select_all = 'არჩევის ინვერტირება';
$html_select_contacts = 'კონტაქტების არჩევა';
$html_loading_image = 'გამოსახულების ატვირთვა';
$html_send_confirmed = 'თქვენი ფოსტა მიღებულია გასაგზავნად';
$html_no_sendaction = 'მოქმედება არ არის ჩართული. სცადეთ JavaScript-ის ჩართვა.';
$html_error_occurred = 'შეცდომა';
$html_prefs_file_error = 'კონფიგურაციის ფაილი ვერ გაიხსნა';
$html_wrap = 'გაგზავნილ წერილებში ახალ ხაზზე გადასატანი სიმბოლოების რაოდენობა:';
$html_wrap_none = 'არა';
$html_usenet_separator = 'გაყავით Usenet სტილში ("-- \n") ხელმოწერამდე';
$html_mark_as = 'მონიშნეთ როგორც';
$html_read = 'კითხვა';
$html_unread = 'წაუკითხავი';
$html_encoding_label = 'სიმბოლოთა კოდირება:';
$html_add = 'დამატება';
$html_contacts = '%1$s კონტაქტები';
$html_modify = 'შეცვლა';
$html_back = 'უკან';
$html_contact_add = 'ახალი კონტაქტის ჩამატება';
$html_contact_mod = 'შეცვალეთ კონტაქტი';
$html_contact_first = 'სახელი';
$html_contact_last = 'გვარი';
$html_contact_nick = 'ზედმეტსახელი';
$html_contact_mail = 'ელექტრონული ფოსტა';
$html_contact_list = 'კონტაქტების სია %1$s';
$html_contact_del = 'საკონტაქტო სიიდან';
$html_contact_count = '%1$d კონტაქტების';
$html_contact_err1 = 'კონტაქტების მაქსიმალური რიცზვი არის "%1$d"';
$html_contact_err2 = 'თქვენ ვერ ჩაამატებთ ახალ კონტაქტს';
$html_contact_err3 = 'თქვენ არ გაქვთ კონტაქტების სიის ნახვის უფლება';
$html_contact_none = 'კონტაქტები არ არიან არჩეულნი';
$html_del_msg = 'არჩეული წერილების წაშლა?';
$html_down_mail = 'ჩამოტვირთვა';
$original_msg = '--ორიგინალი წერილი--';
$to_empty = 'ველი "ვის" უნდა იყოს შევსებული';
$html_images_warning = 'თქვენივე უსაფრთხოებისთვის გარე სურათები არ არის ნაჩვენები';
$html_images_display = 'სურათების ჩვენება';
$html_smtp_error_no_conn = 'ვერ განხორციელდა  SMTP კავშირი';
$html_smtp_error_unexpected = 'მოულოდნელი SMTP პასუხი:';
$lang_could_not_connect = 'შეუძლებელია სერვერთან დაკავშირება';
$lang_invalid_msg_num = 'გამოსახულების ცუდი ნომერი';
$html_file_upload_attack = 'სავარაუდო შეტევო ფაილის ატვირთვის მეშვეობით';
$html_invalid_email_address = 'არასწორი ელექტრონული ფოსტის მისამართი';
$html_invalid_msg_per_page = 'წერილების არასწორი რაოდენობა გვერდზე';
$html_invalid_wrap_msg = 'წერილის არასწორი სიგანე';
$html_seperate_msg_win = 'წერილები ცალკე ფანჯარაში';
$html_err_file_contacts = 'კონტაქტების ფაილი რედაქტირებისთვის ვერ გაიხსნება.';
$html_session_file_error = 'ამ სესიაში დასაწერი ფაილი ვერ გაიხსნა.';
$html_login_not_allowed = 'ანგარიში მიღებულია და მიმდინარეობს სერვერთან დაკავშირება';
$lang_err_send_delay = 'თქვენ უნდა დაიცადოთ, სანამ გაგზავნით სხვა წერილებს (%1$d წამი)';
$html_search = 'ძიება';

==> nocc-1.9.1.tbz: www/nocc/lang/ka.php <==
<?php
/**
 * Language configuration file for NOCC
 *
 * Copyright 2001 Nicolas Chalanset <nicocha@free.fr>
 * Copyright 2001 Olivier Cahagne <cahagn_o@epita.fr>
 *
 * This file is part of NOCC. NOCC is free software under the terms of the
 * GNU General Public License. You should have received a copy of the license
 * along with NOCC.  If not, see <http://www.gnu.org/licenses/>.
 *
 * @package    NOCC
 * @subpackage Translations
 * @license    http://www.gnu.org/licenses/ GNU General Public License
 * @version    SVN: $Id: ka.php 2396 2011-02-14 16:47:29Z siebrand $
 */
/** Georgian (ქართული)
 * 
 * See the qqq 'language' for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author David1010
 * @author გიორგიმელა
 */

$default_date_format = '%d.%m.%Y';
$no_locale_date_format = '%d.%m.%Y';
$default_time_format = '%H:%M';
$err_user_empty = 'სახელის ველი ცარიელია';
$err_passwd_empty = 'პაროლის ველი ცარიელია';
$alt_delete = 'წაშალეთ არჩეული წერილები';
$alt_delete_one = 'წაშალეთ ეს წერილები';
$alt_new_msg = 'ახალი წერილი';
$alt_reply = 'უპასუხეთ ავტორს';
$alt_reply_all = 'უპასუხეთ ყველას';
$alt_forward = 'გაგზავნა';
$alt_next = 'შემდეგი';
$alt_prev = 'წინა';
$title_next_page = 'შემდეგი გვერდი';
$title_prev_page = 'წინა გვერდი';
$title_next_msg = 'შემდეგი შეტყობინება';
$title_prev_msg = 'წინა წერილი';
$html_theme_label = 'გაფორმება:';
$html_welcome = 'კეთილი იყოს თქვენი მობრძანება %1$s';
$html_login = 'შესვლა';
$html_user_label = 'მომხმარებელი:';
$html_passwd_label = 'პაროლი';
$html_submit = 'შენახვა';
$html_help = 'დახმარება';
$html_server_label = 'სერვერი:';
$html_wrong = 'პაროლი ან ანგარიშის სახელი არასწორია';
$html_retry = 'გამეორება';
$html_remember = 'დაიმახსოვრება';
$html_lang_label = 'ენა:';
$html_msgperpage_label = 'წერილები ერთ გვერდზე:';
$html_preferences = 'კონფიგურაცია';
$html_full_name_label = 'სრული სახელი:';
$html_email_address_label = 'ელექტრონული ფოსტის მისამართი:';
$html_bccself = 'დაიტოვეთ ასლი';
$html_hide_addresses = 'დამალეთ მისამართი';
$html_outlook_quoting = 'ციტირება Outlook-ის სტილში';
$html_reply_to = 'უპასუხეთ';
$html_use_signature = 'გამოიყენეთ ხელმოწერა';
$html_signature = 'ხელმოწერ';
$html_signature_label = 'ხელმოწერა:';
$html_reply_leadin_label = 'პასუხის შესავალი:';
$html_prefs_updated = 'კონფიგურაცია განახლდა';
$html_manage_folders_link = 'IMAP ფოლდერების მართვა';
$html_manage_filters_link = 'საფოსტო ფილტრების მართვა';
$html_use_graphical_smilies = 'გამოიყენეთ გრაფიკული სმაილები';
$html_sent_folder_label = 'გაგზავნილი წერილების ასლების შენახვა სპეციალურ ფოლდერში';
$html_trash_folder_label = 'წაშლილი წერილების გადატანა სპეციალურ ფოლდერში:';
$html_colored_quotes = 'გაფერადებული ციტატები';
$html_display_struct = 'სტრუქტურის ტექსტის ჩვენება';
$html_send_html_mail = 'გაგზავნეთ წერილები HTML ფორმატში';
$html_folders = 'ფოლდერები';
$html_folders_create_failed = 'ფოლდერი ვერ შეიქმნა!';
$html_folders_sub_failed = 'ფოლდერის გამოწერა შეუძლებელია!';
$html_folders_unsub_failed = 'ფოლდერიდან გამოწერის შეწყვეტა შეუძლებელია';
$html_folders_rename_failed = 'ფოლდერის სახელის შეცვლა შეუძლებელია';
$html_folders_updated = 'ფოლდერები შენახულია';
$html_folder_subscribe = 'გამოწერა';
$html_folder_rename = 'სახელის შეცვლა';
$html_folder_create = 'ახალი ფოლდერის შექმნა ახალი სახელით';
$html_folder_remove = 'გამოწერის შეწყვეტა';
$html_folder_delete = 'წაშლა';
$html_folder_to = 'მდე';
$html_filter_remove = 'წაშლა';
$html_filter_body = 'წერილის სხეული';
$html_filter_subject = 'წერილის თემა';
$html_filter_to = '"ვის" ველი';
$html_filter_cc = '"ასლი" ველი';
$html_filter_from = '"ვისგან" ველი';
$html_filter_change_tip = 'ცვლილებების შესატანად უბრალოდ გადაწერეთ ფილტრი';
$html_reapply_filters = 'ფილტრების თავიდან ჩართვა';
$html_filter_contains = 'შეიცავს';
$html_filter_name = 'ფილტრის სახელი';
$html_filter_action = 'ფილტრის მოქმედება';
$html_filter_moveto = 'გადატანა';
$html_select_one = '--აირჩიეთ რომელიმე--';
$html_and = 'და';
$html_new_msg_in = 'ახალი შეტყობინებები';
$html_or = 'ან';
$html_move = 'გადატანა';
$html_copy = 'ასლის შექმნა';
$html_messages_to = 'არჩეული წერილები';
$html_gotopage = 'გადატანა გვერდზე';
$html_gotofolder = 'გადასვლა ფოლდერში';
$html_other_folders = 'ფოლდერების სია';
$html_page = 'გვერდი';
$html_of = 'დან';
$html_view_header = 'წერილის სათაურის ხილვა';
$html_remove_header = 'სათაურის დამალვა';
$html_inbox = 'შესული წერილები';
$html_new_msg = 'წერა';
$html_reply = 'პასუხი';
$html_reply_short = 'ვის:';
$html_reply_all = 'უპასუხეთ ყველას';
$html_forward = 'გადაგზავნა';
$html_forward_short = 'წინ:';
$html_forward_info = 'გაგზავნილი წერილი იქნება გადაგზავნილი როგორც ამის მიმაგრება.';
$html_delete = 'წაშლა';
$html_new = 'ახალი';
$html_mark = 'წაშლა';
$html_att_label = 'მიმაგრებული ფაილი:';
$html_atts_label = 'მიმაგრებული ფაილი:';
$html_unknown = '[უცნობია]';
$html_part_x = 'ნაწილი %s';
$html_attach = 'ფაილის მიმაგრება';
$html_attach_forget = 'თქვენ უნდა მიამაგროთ ფაილი წერილის გაგზავნამდე';
$html_attach_delete = 'არჩეულის წაშლა';
$html_attach_none = 'თქვენ შეგიძლიათ აირჩიოთ ფაილი კავშირის დასამყარებლად';
$html_sort_by = 'სორტირება';
$html_sort = 'სორტირება';
$html_from = 'გან';
$html_from_label = 'გან:';
$html_subject = 'თემა';
$html_subject_label = 'თემა:';
$html_date = 'თარიღი';
$html_date_label = 'თარიღი:';
$html_sent_label = 'გაიგზავნა:';
$html_wrote = 'დაწერა';
$html_size = 'ზომა';
$html_totalsize = 'სულ ზომა';
$html_kb = 'კბ';
$html_mb = 'მბ';
$html_gb = 'გბ';
$html_bytes = 'ბ';
$html_filename = 'ფაილის სახელი';
$html_to = 'ვის';
$html_to_label = 'ადრესატი:';
$html_cc = 'ასლი';
$html_cc_label = 'ასლი:';
$html_bcc_label = 'Bcc:';
$html_nosubject = 'არ არის თემა';
$html_send = 'გაგზავნა';
$html_cancel = 'გაუქმება';
$html_no_mail = 'წერილები არ არის.';
$html_logout = 'გასვლა';
$html_msg = 'წერილი';
$html_msgs = 'წერილები';
$html_configuration = 'ეს სერვერი არის არასწორედ დაყენებული!';
$html_priority = 'პრიორიტეტი';
$html_priority_label = 'პრიორიტეტი:';
$html_lowest = 'ყველაზე დაბალი';
$html_low = 'დაბალი';
$html_normal = 'ნორმალური';
$html_high = 'მაღალი';
$html_highest = 'ყველაზე მაღალი';
$html_flagged = 'მონიშნული';
$html_spam = 'სპამი';
$html_spam_warning = 'ეს შეტყობინება კლასიფიცირდა, როგორც სპამი.';
$html_receipt = 'მოითხოვეთ წაკითხვის დადასტურება';
$html_select = 'არჩევა';
$html_select_all = 'არჩევის ინვერტირება';
$html_select_contacts = 'კონტაქტების არჩევა';
$html_loading_image = 'გამოსახულების ატვირთვა';
$html_send_confirmed = 'თქვენი ფოსტა მიღებულია გასაგზავნად';
$html_no_sendaction = 'მოქმედება არ არის ჩართული. სცადეთ JavaScript-ის ჩართვა.';
$html_error_occurred = 'შეცდომა';
$html_prefs_file_error = 'კონფიგურაციის ფაილი ვერ გაიხსნა';
$html_wrap = 'გაგზავნილ წერილებში ახალ ხაზზე გადასატანი სიმბოლოების რაოდენობა:';
$html_wrap_none = 'არა';
$html_usenet_separator = 'გაყავით Usenet სტილში ("-- \n") ხელმოწერამდე';
$html_mark_as = 'მონიშნეთ როგორც';
$html_read = 'კითხვა';
$html_unread = 'წაუკითხავი';
$html_encoding_label = 'სიმბოლოთა კოდირება:';
$html_add = 'დამატება';
$html_contacts = '%1$s კონტაქტები';
$html_modify = 'შეცვლა';
$html_back = 'უკან';
$html_contact_add = 'ახალი კონტაქტის ჩამატება';
$html_contact_mod = 'შეცვალეთ კონტაქტი';
$html_contact_first = 'სახელი';
$html_contact_last = 'გვარი';
$html_contact_nick = 'ზედმეტსახელი';
$html_contact_mail = 'ელექტრონული ფოსტა';
$html_contact_list = 'კონტაქტების სია %1$s';
$html_contact_del = 'საკონტაქტო სიიდან';
$html_contact_count = '%1$d კონტაქტების';
$html_contact_err1 = 'კონტაქტების მაქსიმალური რიცზვი არის "%1$d"';
$html_contact_err2 = 'თქვენ ვერ ჩაამატებთ ახალ კონტაქტს';
$html_contact_err3 = 'თქვენ არ გაქვთ კონტაქტების სიის ნახვის უფლება';
$html_contact_none = 'კონტაქტები არ არიან არჩეულნი';
$html_del_msg = 'არჩეული წერილების წაშლა?';
$html_down_mail = 'ჩამოტვირთვა';
$original_msg = '--ორიგინალი წერილი--';
$to_empty = 'ველი "ვის" უნდა იყოს შევსებული';
$html_images_warning = 'თქვენივე უსაფრთხოებისთვის გარე სურათები არ არის ნაჩვენები';
$html_images_display = 'სურათების ჩვენება';
$html_smtp_error_no_conn = 'ვერ განხორციელდა  SMTP კავშირი';
$html_smtp_error_unexpected = 'მოულოდნელი SMTP პასუხი:';
$lang_could_not_connect = 'შეუძლებელია სერვერთან დაკავშირება';
$lang_invalid_msg_num = 'გამოსახულების ცუდი ნომერი';
$html_file_upload_attack = 'სავარაუდო შეტევო ფაილის ატვირთვის მეშვეობით';
$html_invalid_email_address = 'არასწორი ელექტრონული ფოსტის მისამართი';
$html_invalid_msg_per_page = 'წერილების არასწორი რაოდენობა გვერდზე';
$html_invalid_wrap_msg = 'წერილის არასწორი სიგანე';
$html_seperate_msg_win = 'წერილები ცალკე ფანჯარაში';
$html_err_file_contacts = 'კონტაქტების ფაილი რედაქტირებისთვის ვერ გაიხსნება.';
$html_session_file_error = 'ამ სესიაში დასაწერი ფაილი ვერ გაიხსნა.';
$html_login_not_allowed = 'ანგარიში მიღებულია და მიმდინარეობს სერვერთან დაკავშირება';
$lang_err_send_delay = 'თქვენ უნდა დაიცადოთ, სანამ გაგზავნით სხვა წერილებს (%1$d წამი)';
$html_search = 'ძიება';
